@@ -1266,6 +1266,10 @@ xfce_appfinder_window_entry_changed_idle (gpointer data)
     {
       gtk_widget_set_sensitive (window->button_launch, IS_STRING (text));
 
+      /* Clear entry's error icon and tooltip */
+      gtk_entry_set_icon_from_icon_name (GTK_ENTRY (window->entry), GTK_ENTRY_ICON_PRIMARY, NULL);
+      gtk_entry_set_icon_tooltip_text (GTK_ENTRY (window->entry), GTK_ENTRY_ICON_PRIMARY, NULL);
+
       pixbuf = xfce_appfinder_model_get_icon_for_command (window->model, text);
       xfce_appfinder_window_update_image (window, pixbuf);
       if (pixbuf != NULL)
@@ -1961,11 +1965,13 @@ xfce_appfinder_window_sort_items (GtkTreeModel *model,
 
   gtk_tree_model_get (model, a, XFCE_APPFINDER_MODEL_COLUMN_TITLE, &title_a, -1);
   normalized = g_utf8_normalize (title_a, -1, G_NORMALIZE_ALL);
+  g_free (title_a);
   title_a = g_utf8_casefold (normalized, -1);
   g_free (normalized);
 
   gtk_tree_model_get (model, b, XFCE_APPFINDER_MODEL_COLUMN_TITLE, &title_b, -1);
   normalized = g_utf8_normalize (title_b, -1, G_NORMALIZE_ALL);
+  g_free (title_b);
   title_b = g_utf8_casefold (normalized, -1);
   g_free (normalized);
 
@@ -1998,6 +2004,6 @@ static gboolean
 xfce_appfinder_should_sort_icon_view (void)
 {
   return gtk_get_major_version () >= 3  &&
-         gtk_get_micro_version () >= 22 &&
+         gtk_get_minor_version () >= 22 &&
          gtk_get_micro_version () >= 27;
 }
